package com.dlsm;

import com.dlsm.config.WebApiConfig;
import com.dlsm.model.EndStation2;
import com.dlsm.model.SellStations;
import com.dlsm.task.MainScheduleManager;
import com.dlsm.transport.impl.WebApiTransport;
import com.dlsm.webapi.GetBus3;
import com.dlsm.webapi.GetEndStations2;
import com.dlsm.webapi.GetSellStations;
import com.dlsm.webapi.base.Mission;
import org.mybatis.spring.annotation.MapperScan;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.transaction.annotation.EnableTransactionManagement;
import org.springframework.context.ApplicationContext;

import java.time.LocalDate;
import java.util.*;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * 客运公交数据采集服务
 * @author xxg
 * @date 2023-02-03
 */

@SpringBootApplication
@EnableTransactionManagement
@MapperScan("com.dlsm.mapper")
public class SpringbootsApplication {

	public static ApplicationContext appctx = null;
	public static Logger logger = LoggerFactory.getLogger(SpringbootsApplication.class);

	public SpringbootsApplication() {
	}


	public static void main(String[] args) {
//		SpringApplication.run(SpringbootsApplication.class, args);

		appctx = SpringApplication.run(SpringbootsApplication.class, args);

		WebApiConfig webApiConfig = (WebApiConfig)appctx.getBean(WebApiConfig.class);
		Mission getSellStations_820574002 = new GetSellStations(webApiConfig.getWebserviceUrl(), webApiConfig.getPartnerID(), webApiConfig.getUtitIDSouth(), webApiConfig.getMd5());
		WebApiTransport webApiTransport1 = new WebApiTransport(getSellStations_820574002);
		Map<String, Object> map1 = webApiTransport1.templateMethod();
		SellStations sellStation1 = (SellStations)map1.get("nzpk");
		String southSellStationID = "";
		if (sellStation1 != null) {
			southSellStationID = sellStation1.getOutId();
		}

		Mission getSellStations2 = new GetSellStations(webApiConfig.getWebserviceUrl(), webApiConfig.getPartnerID(), webApiConfig.getUnitIDMiddle(), webApiConfig.getMd5());
		WebApiTransport webApiTransport2 = new WebApiTransport(getSellStations2);
		Map<String, Object> map2 = webApiTransport2.templateMethod();
		map2.putAll(map1);
		SellStations sellStation2 = (SellStations)map2.get("zxz");
		String middleSellStationID = "";
		if (sellStation2 != null) {
			middleSellStationID = sellStation2.getOutId();
		}

		Mission getEndStationsSouth = new GetEndStations2(webApiConfig.getWebserviceUrl(), webApiConfig.getPartnerID(), webApiConfig.getUtitIDSouth(), webApiConfig.getMd5(), "");
		WebApiTransport webApiTransport_820574002 = new WebApiTransport(getEndStationsSouth);
		Map<String, Object> map_820574002 = webApiTransport_820574002.templateMethod();
		List<Map<String, String>> route_820574002 = new ArrayList();
		Iterator var17 = map_820574002.entrySet().iterator();

		String[] sellStationCodes;
		while(var17.hasNext()) {
			Map.Entry<String, Object> entry = (Map.Entry)var17.next();
			EndStation2 endStation2 = (EndStation2)entry.getValue();
			sellStationCodes = endStation2.getSellStationCode().split(",");

			int var22 = sellStationCodes.length;

			for(int var21 = 0; var21 < var22; ++var21) {
				String stationCode = sellStationCodes[var21];
				Map<String, String> map = new HashMap();
				if (stationCode.equals("0002")) {
					map.put(endStation2.getOutId() + "_" + endStation2.getCityName() + "_" + endStation2.getCityCode(), "0002");
					route_820574002.add(map);
				}

				if (stationCode.equals("0001")) {
					map.put(endStation2.getOutId() + "_" + endStation2.getCityName() + "_" + endStation2.getCityCode(), "0001");
					route_820574002.add(map);
				}
			}
		}

		Mission getEndStationsMiddle = new GetEndStations2(webApiConfig.getWebserviceUrl(), webApiConfig.getPartnerID(), webApiConfig.getUnitIDMiddle(), webApiConfig.getMd5(), "");
		WebApiTransport webApiTransport_820574003 = new WebApiTransport(getEndStationsMiddle);
		Map<String, Object> map_820574003 = webApiTransport_820574003.templateMethod();
		List<Map<String, String>> route_820574003 = new ArrayList();
		Iterator var42 = map_820574003.entrySet().iterator();

		String dateString;
		while(var42.hasNext()) {
			Map.Entry<String, Object> entry = (Map.Entry)var42.next();
			EndStation2 endStation2 = (EndStation2)entry.getValue();
			sellStationCodes = endStation2.getSellStationCode().split(",");
			String[] var27 = sellStationCodes;
			int var26 = sellStationCodes.length;

			for(int var25 = 0; var25 < var26; ++var25) {
				dateString = var27[var25];
				Map<String, String> map = new HashMap();
				if (dateString.equals("0002")) {
					map.put(endStation2.getOutId() + "_" + endStation2.getCityName() + "_" + endStation2.getCityCode(), "0002");
					route_820574003.add(map);
				}

				if (dateString.equals("0001")) {
					map.put(endStation2.getOutId() + "_" + endStation2.getCityName() + "_" + endStation2.getCityCode(), "0001");
					route_820574003.add(map);
				}
			}
		}

		LocalDate now = LocalDate.now();
		String year = String.valueOf(now.getYear());
		String monthValue = String.valueOf(now.getMonthValue());
		String dayOfMonth = String.valueOf(now.getDayOfMonth());
		dateString = year + "-" + monthValue + "-" + dayOfMonth;
		List<GetBus3> busList_820574002 = new ArrayList();
		Iterator var51 = route_820574002.iterator();

		String key;
		String desStationID;
		String desStationName;
		while(var51.hasNext()) {
			Map<String, String> map = (Map)var51.next();
			Iterator var29 = map.entrySet().iterator();

			while(var29.hasNext()) {
				Map.Entry<String, String> entry = (Map.Entry)var29.next();
				key = (String)entry.getKey();
				String keyCode = "";
				keyCode = key.substring(0, key.indexOf("_"));
				desStationID = key.substring(key.indexOf("_") + 1, key.lastIndexOf("_"));
				desStationName = key.substring(key.lastIndexOf("_") + 1);
				GetBus3 bus = new GetBus3(webApiConfig.getWebserviceUrl(), webApiConfig.getPartnerID(), webApiConfig.getUtitIDSouth(), dateString, key.substring(0, key.indexOf("_")), desStationID, desStationName, "", "0", "0", webApiConfig.getMd5());
				busList_820574002.add(bus);
			}
		}

		List<GetBus3> busList_820574003 = new ArrayList();
		Iterator var55 = route_820574003.iterator();

		while(var55.hasNext()) {
			Map<String, String> map = (Map)var55.next();
			Iterator var59 = map.entrySet().iterator();

			while(var59.hasNext()) {
				Map.Entry<String, String> entry = (Map.Entry)var59.next();
				key = (String)entry.getKey();
				desStationID = key.substring(0, key.indexOf("_"));
				desStationName = key.substring(key.indexOf("_") + 1, key.lastIndexOf("_"));
				String cityCode = key.substring(key.lastIndexOf("_") + 1);
				GetBus3 bus = new GetBus3(webApiConfig.getWebserviceUrl(), webApiConfig.getPartnerID(), webApiConfig.getUnitIDMiddle(), dateString, desStationID, desStationName, cityCode, "", "0", "0", webApiConfig.getMd5());
				busList_820574003.add(bus);
			}
		}

		ExecutorService excutor = Executors.newCachedThreadPool();
		ExecutorService manager = Executors.newCachedThreadPool();
		MainScheduleManager mainScheduleManager_820574002 = new MainScheduleManager();
		mainScheduleManager_820574002.init(busList_820574002, excutor, manager);
		mainScheduleManager_820574002.manageTask();
		MainScheduleManager mainScheduleManager_820574003 = new MainScheduleManager();
		mainScheduleManager_820574003.init(busList_820574003, excutor, manager);
		mainScheduleManager_820574003.manageTask();

	}
}
