package com.dlsm.webapi;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import com.dlsm.SpringbootsApplication;
import com.dlsm.mapper.BusMapper;
import com.dlsm.model.Bus3;
import com.dlsm.service.impl.Bus3ServiceImpl;
import com.dlsm.webapi.base.Mission;
import org.dom4j.Document;
import org.dom4j.Element;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.DigestUtils;

/**
 * 客运公交数据采集保存
 * @author xxg
 * @date 2023-02-03
 */

public class GetBus3 extends Mission {
    Logger logger = LoggerFactory.getLogger(GetBus3.class);

    BusMapper busMapper;

    private String url;
    private final String PATH = "/st6_ticket_hsga/sell/GetBus3?";
    private String partnerID;
    private String signType;
    private String signData;
    private String unitID;
    private String busDate;
    private String desStationID;
    private String sellStationID;
    private String timeHour;
    private String timeMinutes;
    private String md5;
    private String desStationName;
    private String cityCode;

    public GetBus3() {
    }

    public GetBus3(String url, String partnerID, String unitID, String busDate, String desStationID, String desStationName, String cityCode, String sellStationID, String timeHour, String timeMinutes, String md5) {
        this.url = url;
        this.partnerID = partnerID;
        this.signType = "";
        this.unitID = unitID;
        this.busDate = busDate;
        this.desStationID = desStationID;
        this.desStationName = desStationName;
        this.sellStationID = sellStationID;
        this.timeHour = timeHour;
        this.timeMinutes = timeMinutes;
        this.md5 = md5;
        this.cityCode = cityCode;
    }

    public String getSignData() {
        this.signData = "unitID=" + this.getUnitID() + "&busDate=" + this.getBusDate() + "&desStationID=" + this.getDesStationID() + "&sellStationID=" + this.getSellStationID() + "&timeHour=" + this.getTimeHour() + "&timeMinutes=" + this.getTimeMinutes() + this.getMd5();
        this.signData = DigestUtils.md5DigestAsHex(this.signData.getBytes());
        return this.signData;
    }

    public String getGetBus3Message() {
        return "partnerID=" + this.getPartnerID() + "&signType=&signData=" + this.getSignData() + "&unitID=" + this.getUnitID() + "&busDate=" + this.getBusDate() + "&desStationID=" + this.getDesStationID() + "&sellStationID=" + this.getSellStationID() + "&timeHour=" + this.getTimeHour() + "&timeMinutes=" + this.getTimeMinutes() + "&ran=";
    }

    public String getGetUrl() {
        String url = this.url + "/st6_ticket_hsga/sell/GetBus3?" + this.getGetBus3Message();
        return url;
    }

    public Map<String, Object> parseAndSave(Document doc) {
        Map<String, Object> map = new HashMap();
        List<Bus3> bus3List = new ArrayList();
        Element root = doc.getRootElement();
        Iterator it = root.elementIterator("body");

        label38:
        while(it.hasNext()) {
            Element element = (Element)it.next();
            Iterator itEndStation2 = element.elementIterator("Bus3");

            while(true) {
                Element endStation2Element;
                do {
                    if (!itEndStation2.hasNext()) {
                        continue label38;
                    }

                    endStation2Element = (Element)itEndStation2.next();
                } while(!"0001".equals(endStation2Element.elementText("SellStationID")) && !"0002".equals(endStation2Element.elementText("SellStationID")));

                Bus3 bus3 = new Bus3();
                bus3.setCreateTime(new Date());
                bus3.setOutId(endStation2Element.elementText("ID"));

                try {
                    Date time = (new SimpleDateFormat("yyyy-MM-dd HH:mm:ss")).parse(endStation2Element.elementText("Time"));
                    bus3.setTime(time);
                } catch (ParseException var12) {
                    var12.printStackTrace();
                }

                bus3.setRouteID(endStation2Element.elementText("RouteID"));
                bus3.setRouteName(endStation2Element.elementText("RouteName"));
                bus3.setSellStationID(endStation2Element.elementText("SellStationID"));
                bus3.setSellStationName(endStation2Element.elementText("SellStationName"));
                bus3.setEndStationID(endStation2Element.elementText("EndStationID"));
                bus3.setEndStationName(endStation2Element.elementText("EndStationName"));
                bus3.setDesStationID(this.desStationID);
                bus3.setDesStationName(this.desStationName);
                bus3.setCityCode(this.cityCode);
                bus3.setCanSell(endStation2Element.elementText("CanSell"));
                bus3.setTypeID(endStation2Element.elementText("TypeID"));
                bus3.setTypeName(endStation2Element.elementText("TypeName"));
                bus3.setCheckGate(endStation2Element.elementText("CheckGate"));
                bus3.setGuidePrice(endStation2Element.elementText("GuidePrice"));
                bus3.setFullPrice(endStation2Element.elementText("FullPrice"));
                bus3.setHalfPrice(endStation2Element.elementText("HalfPrice"));
                bus3.setSeatRemain(endStation2Element.elementText("SeatRemain"));
                bus3.setBedFullPrice(endStation2Element.elementText("BedFullPrice"));
                bus3.setBedHalfPrice(endStation2Element.elementText("BedHalfPrice"));
                bus3.setBedRemain(endStation2Element.elementText("BedRemain"));
                bus3.setAdditionalFullPrice(endStation2Element.elementText("AdditionalFullPrice"));
                bus3.setAdditionalHalfPrice(endStation2Element.elementText("AdditionalHalfPrice"));
                bus3.setAdditionalRemain(endStation2Element.elementText("AdditionalRemain"));
                bus3.setKind(endStation2Element.elementText("Kind"));
                bus3.setTotalSeat(endStation2Element.elementText("TotalSeat"));
                bus3.setVehicleModel(endStation2Element.elementText("VehicleModel"));
                bus3.setTakeChildrenQuantit(endStation2Element.elementText("TakeChildrenQuantit"));
                bus3.setAddStatus(endStation2Element.elementText("AddStatus"));
                bus3.setUnitID(endStation2Element.elementText("UnitID"));
                bus3.setBusStatus(endStation2Element.elementText("BusStatus"));
                bus3.setCanChildrenQuantity(endStation2Element.elementText("CanChildrenQuantity"));
                bus3.setCanHalfQuantity(endStation2Element.elementText("CanHalfQuantity"));
                bus3.setTotalCount(endStation2Element.elementText("TotalCount"));
                bus3.setRunTime(endStation2Element.elementText("RunTime"));
                bus3.setLicenseTagNo(endStation2Element.elementText("LicenseTagNo"));
                bus3.setFastNote(endStation2Element.elementText("FastNote"));
                bus3.setStationAlias(endStation2Element.elementText("StationAlias"));
                this.logger.info(bus3.toString());
                bus3List.add(bus3);
                map.put(bus3.getRouteName(), bus3);
            }
        }

        if (bus3List.size() > 0) {
            this.save(bus3List);
        }

        return map;
    }

    private boolean save(List<Bus3> bus3List) {

        Iterator var3 = bus3List.iterator();

        while(var3.hasNext()) {
            Bus3 bus3 = (Bus3)var3.next();
            this.busMapper = (BusMapper) SpringbootsApplication.appctx.getBean(BusMapper.class);
            this.busMapper.insertBus3(bus3);
        }

        return false;
    }

    public Logger getLogger() {
        return this.logger;
    }

    public String getUrl() {
        return this.url;
    }

    public String getPATH() {
        return "/st6_ticket_hsga/sell/GetBus3?";
    }

    public String getPartnerID() {
        return this.partnerID;
    }

    public String getSignType() {
        return this.signType;
    }

    public String getUnitID() {
        return this.unitID;
    }

    public String getBusDate() {
        return this.busDate;
    }

    public String getDesStationID() {
        return this.desStationID;
    }

    public String getSellStationID() {
        return this.sellStationID;
    }

    public String getTimeHour() {
        return this.timeHour;
    }

    public String getTimeMinutes() {
        return this.timeMinutes;
    }

    public String getMd5() {
        return this.md5;
    }

    public String getDesStationName() {
        return this.desStationName;
    }

    public String getCityCode() {
        return this.cityCode;
    }

    public void setLogger(Logger logger) {
        this.logger = logger;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public void setPartnerID(String partnerID) {
        this.partnerID = partnerID;
    }

    public void setSignType(String signType) {
        this.signType = signType;
    }

    public void setSignData(String signData) {
        this.signData = signData;
    }

    public void setUnitID(String unitID) {
        this.unitID = unitID;
    }

    public void setBusDate(String busDate) {
        this.busDate = busDate;
    }

    public void setDesStationID(String desStationID) {
        this.desStationID = desStationID;
    }

    public void setSellStationID(String sellStationID) {
        this.sellStationID = sellStationID;
    }

    public void setTimeHour(String timeHour) {
        this.timeHour = timeHour;
    }

    public void setTimeMinutes(String timeMinutes) {
        this.timeMinutes = timeMinutes;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public void setDesStationName(String desStationName) {
        this.desStationName = desStationName;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }


}

