package com.dlsm.webapi;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import com.dlsm.SpringbootsApplication;
import com.dlsm.mapper.EndStation2Mapper;
import com.dlsm.model.Bus3;
import com.dlsm.model.EndStation2;
import com.dlsm.service.impl.Bus3ServiceImpl;
import com.dlsm.service.impl.EndStation2ServiceImpl;
import com.dlsm.webapi.base.Mission;
import org.dom4j.Document;
import org.dom4j.Element;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.DigestUtils;

/**
 * 客运公交数据采集保存
 * @author xxg
 * @date 2023-02-03
 */

public class GetEndStations2 extends Mission {
    Logger logger = LoggerFactory.getLogger(GetEndStations2.class);

    EndStation2Mapper endStation2Mapper;

    private String url;
    private final String PATH = "/st6_ticket_hsga/sell/GetEndStations2?";
    private String partnerID;
    private String signType;
    private String signData;
    private String unitID;
    private String seek;
    private String md5;

    public GetEndStations2(String url, String partnerID, String unitID, String md5, String seek) {
        this.url = url;
        this.partnerID = partnerID;
        this.unitID = unitID;
        this.md5 = md5;
        this.seek = seek;
    }

    public String getSignData() {
        this.signData = "unitID=" + this.getUnitID() + "&seek=" + this.getMd5();
        this.signData = DigestUtils.md5DigestAsHex(this.signData.getBytes());
        return this.signData;
    }

    public String getGetEndStations2Message() {
        return "partnerID=" + this.getPartnerID() + "&signType=&signData=" + this.getSignData() + "&unitID=" + this.getUnitID() + "&seek=" + this.getSeek() + "&ran=";
    }

    public String getGetUrl() {
        String url = this.url + "/st6_ticket_hsga/sell/GetEndStations2?" + this.getGetEndStations2Message();
        return url;
    }

    public Map<String, Object> parseAndSave(Document doc) {
        Map<String, Object> map = new HashMap();
        List<EndStation2> endStation2List = new ArrayList();
        Element root = doc.getRootElement();
        Iterator it = root.elementIterator("body");

        while(it.hasNext()) {
            Element element = (Element)it.next();
            Iterator itEndStation2 = element.elementIterator("EndStation2");

            while(itEndStation2.hasNext()) {
                Element endStation2Element = (Element)itEndStation2.next();
                EndStation2 endStation2 = new EndStation2();
                endStation2.setCreateTime(new Date());
                endStation2.setOutId(endStation2Element.elementText("ID"));
                endStation2.setName(endStation2Element.elementText("Name"));
                endStation2.setInputCode(endStation2Element.elementText("InputCode"));
                endStation2.setAreaCode(endStation2Element.elementText("AreaCode"));
                endStation2.setAreaName(endStation2Element.elementText("AreaName"));
                endStation2.setAreaType(endStation2Element.elementText("AreaType"));
                endStation2.setSellStationCode(endStation2Element.elementText("SellStationCode"));
                endStation2.setCityCode(endStation2Element.elementText("CityCode"));
                endStation2.setCityName(endStation2Element.elementText("CityName"));
                endStation2.setProvinceCode(endStation2Element.elementText("ProvinceCode"));
                endStation2.setProvinceName(endStation2Element.elementText("ProvinceName"));
                endStation2.setUnitID(endStation2Element.elementText("UnitID"));
                endStation2.setUnitName(endStation2Element.elementText("UnitName"));
                endStation2.setPhoneCode(endStation2Element.elementText("PhoneCode"));
                endStation2.setPYInPutCode(endStation2Element.elementText("PYInPutCode"));
                endStation2.setLimitType(endStation2Element.elementText("LimitType"));
                this.logger.info(endStation2.toString());
                endStation2List.add(endStation2);
                map.put(endStation2.getName(), endStation2);
            }
        }

        this.save(endStation2List);
        return map;
    }

    private boolean save(List<EndStation2> endStation2List) {

        this.endStation2Mapper = (EndStation2Mapper) SpringbootsApplication.appctx.getBean(EndStation2Mapper.class);
        Iterator var3 = endStation2List.iterator();

        while(var3.hasNext()) {
            EndStation2 station = (EndStation2)var3.next();
            this.endStation2Mapper.insertEndStation2(station);
        }

        return false;
    }

    public Logger getLogger() {
        return this.logger;
    }

    public String getUrl() {
        return this.url;
    }

    public String getPATH() {
        return "/st6_ticket_hsga/sell/GetEndStations2?";
    }

    public String getPartnerID() {
        return this.partnerID;
    }

    public String getSignType() {
        return this.signType;
    }

    public String getUnitID() {
        return this.unitID;
    }

    public String getSeek() {
        return this.seek;
    }

    public String getMd5() {
        return this.md5;
    }

    public void setLogger(Logger logger) {
        this.logger = logger;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public void setPartnerID(String partnerID) {
        this.partnerID = partnerID;
    }

    public void setSignType(String signType) {
        this.signType = signType;
    }

    public void setSignData(String signData) {
        this.signData = signData;
    }

    public void setUnitID(String unitID) {
        this.unitID = unitID;
    }

    public void setSeek(String seek) {
        this.seek = seek;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

}
